==> KakiWiki-0.9.9.tar.gz: KakiWiki-0.9.9/src/ToWikiHtml.rb <==
module Wiki

require 'ToHtml.rb'

class ToWikiHtml < ToHtml

	def initialize(page_data_source, output = STDOUT)
		super(output)
		@page_data_source = page_data_source
		self.link_base_uri = ''
		self.default_lang_list = nil
		@link_html_cache = {}
	end

	attr "link_base_uri", true;
	attr "default_lang_list", true;

	def visit_link(element)
		link_id = element.label.untaint()
		page_name, page_lang, page_version = @page_data_source.parse_page_id(link_id)
		if self.default_lang_list then
			link_html = @link_html_cache[link_id] 
			unless link_html then
				lang_list = self.default_lang_list
				lang_list = [page_lang] + lang_list if page_lang 

				page_id = @page_data_source.suitable_page_id(page_name, lang_list, page_version) 
				if page_id then
					page_name, page_lang, page_version = @page_data_source.parse_page_id(page_id)
					page_title = @page_data_source.page_property(page_name, page_lang)['page_title']
					link_html = %Q!<a href="#{link_base_uri}#{URI.escape(element.label)}">#{CGI.escapeHTML(page_title)}</a>!
				else
					link_html = %Q!#{CGI.escapeHTML(element.label)}<a href="#{link_base_uri}#{URI.escape(element.label)}">?</a>!
				end
				@link_html_cache[link_id] = link_html
			end
		else
			if @page_data_source.exist_page?(page_name) then
				link_html = %Q!<a href="#{link_base_uri}#{URI.escape(element.label)}">#{CGI.escapeHTML(element.label)}</a>!
			else
				link_html = %Q!#{CGI.escapeHTML(element.label)}<a href="#{link_base_uri}#{URI.escape(element.label)}">?</a>!
			end
		end
		output << link_html
	end

	def visit_page(element)
		element.children_accept(self)
		output
	end

end

end

==> KakiWiki-1.0.3.tar.gz: KakiWiki-1.0.3/src/ToWikiHtml.rb <==
module Wiki

require 'ToHtml.rb'


class ToWikiHtml < ToHtml

	def initialize(page_data_source, output = STDOUT)
		super(output)
		@page_data_source = page_data_source
		@link_html_cache = {}
		@inter_wiki_name_table = nil
		self.link_base_uri = ''
		self.language_list = nil
		self.page_language = nil
		self.sub_page_mode = false
	end

	attr :link_base_uri, true;
	attr :language_list, true;
	attr :page_language, true;
	attr :sub_page_mode, true;

	def visit_link(element)
		link_id = element.label.untaint()
		page_name, page_lang, page_version = @page_data_source.parse_page_id(link_id)
		if self.sub_page_mode then
			link_html = @link_html_cache[link_id] 
			unless link_html then
				lang_list = self.language_list
				lang_list = [page_lang] + lang_list if page_lang 

				page_id = @page_data_source.suitable_page_id(page_name, lang_list, page_version) 
				if page_id then
					page_name, page_lang, page_version = @page_data_source.parse_page_id(page_id)
					page_title = @page_data_source.page_property(page_name, page_lang)['page_title']
					link_html = %Q!<a href="#{link_base_uri}#{URI.escape(element.label)}">#{CGI.escapeHTML(page_title)}</a>!
				else
					link_html = %Q!#{CGI.escapeHTML(element.label)}<a href="#{link_base_uri}#{URI.escape(element.label)}">?</a>!
				end
				@link_html_cache[link_id] = link_html
			end
		else
			if @page_data_source.exist_page?(page_name) then
				link_html = %Q!<a href="#{link_base_uri}#{URI.escape(element.label)}">#{CGI.escapeHTML(element.label)}</a>!
			else
				link_html = %Q!#{CGI.escapeHTML(element.label)}<a href="#{link_base_uri}#{URI.escape(element.label)}">?</a>!
			end
		end
		output << link_html
	end


	def visit_page(element)
		element.children_accept(self)
		output
	end

protected
	def inter_wiki_name_document()
		unless @inter_wiki_name_document then
			language_list = [self.page_language] + self.language_list
			inter_wiki_name_page_id = @page_data_source.suitable_page_id('InterWikiName', language_list)
			if inter_wiki_name_page_id then
				inter_wiki_name_page_name, inter_wiki_name_page_lang, = @page_data_source.parse_page_id(inter_wiki_name_page_id)
				inter_wiki_name_doc = @page_data_source.load_page_document(inter_wiki_name_page_name, inter_wiki_name_page_lang)
				if inter_wiki_name_doc then
					@inter_wiki_name_document = inter_wiki_name_doc ;
				end
			end
		end
		@inter_wiki_name_document
	end
end

end
